# VideoJS Media block

The VideoJS Media block module is an ADA/508 compliant media player that works
well with the Media, Media Library, and Layout Builder modules in Drupal core.
[VideoJS](https://videojs.com/) is a very mature, open-source video library
primarily sponsored by Brightcove, with [a wealth of plugins](https://videojs.com/plugins/).

For a full description of the module, visit the
[project page](https://www.drupal.org/project/videojs_mediablock).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/videojs_mediablock).


## Table of contents

- Features
- Requirements
- Recommended modules
- Installation
- Known problems
- Instructions
- Configuration
- Maintainers


## Features

- Compliant with the Americans with Disabilities Act (ADA) standards for
  video, by providing configurable and themable closed-captions support.

- The VideoJS Media block module creates a custom blocktype with three
  fields to input a Media file, an optional poster image, and an optional .vtt
  subtitle file. To please site builders and content managers, Custom VideoJS
  Media blocks are videos with controls that fit anywhere a Block can go.

- To please developer/themers, the sole .twig file can be customized. Fields
  can be added, removed, changed yourself, when managed with
  [Drupal Configuration Management](https://www.drupal.org/docs/configuration-management).

- Responsive, with no need to input height or width values.

- Besides the default player skin,
  [four more are included](https://www.mux.com/blog/the-new-video-js-themes).
  And of course it is easy to [customize skins](https://videojs.com/guides/skins/).

- Developed around the core Media and Media Library modules. No contributed
  modules are necessary.

- Media can be uploaded files or hosted remotely on either YouTube or Vimeo.


## Requirements

The core Media module is required, and NPM must be installed on the server.

[This patch](https://www.drupal.org/files/issues/2020-07-02/3062376-34.patch)
is also required, resulting from the thread below, until a patched release
of Drupal core becomes available, (Drupal 11 it seems). This issue also limits
the module to Drupal 10 websites and above.

- [Issue 3062376: Template suggestions for custom block view modes](https://www.drupal.org/project/drupal/issues/3062376#comment-14885212)


## Recommended modules

Drupal core modules
- Media Library
- Layout Builder


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Known problems

Support for mp3 audio files requires further logic to be written into the .twig
file. Automatic mime detection logic should also be written too. Doing these
things will allow for supporting all of the formats that VideoJS supports.

YouTube and Vimeo support has been removed for the time-being.
[Refer to this commit](https://git.drupalcode.org/project/videojs_mediablock/-/tree/cb294102c39f83fdc5b7e8e42da25ae319cddb22)
if you want to try to use it.


## Instructions

Upon installation, from within the module's root folder, you must install NPM
related libraries with the 'npm install', or 'npm update' commands. Over time,
you'll need to keep these libraries up-to-date using NPM, or (NVM which I've
only been studying recently).

Create a new custom VideoJS Media block at /block/add/videojs_mediablock. The
media field is required, while the poster and subtitle fields are optional.

New VideoJS Media blocks will be listed at /admin/structure/block/block-content.
If your website uses a great many videos, you might be able to use Views,
exposed filters, taxonomies, etc. to create a better panel for Content Managers
to sort through.

Place your custom blocks anywhere at /admin/structure/block or use Layout
Builder.

If you're using remotely-hosted video, you might need to
[create a CORS exception](https://enable-cors.org/server_apache.html) for
either YouTube or Vimeo.


## Configuration

The module has no menu or modifiable settings. There is no configuration. When
enabled, the module will prevent the blocktype 'VideoJS Media Block'.


## Credits

This module wouldn't be possible without the recent development taking place at
this thread:

- [Issue 3062376: Template suggestions for custom block view modes](https://www.drupal.org/project/drupal/issues/3062376#comment-14885212)


## Support

[Paid support available.](https://micronugget.com/contact)


## Maintainers

- Amstercad - [amstercad](https://www.drupal.org/u/amstercad)
